@@ -617,7 +617,7 @@ gst_rtsp_session_allow_expire (GstRTSPSession * session)
 /**
  * gst_rtsp_session_next_timeout_usec:
  * @session: a #GstRTSPSession
- * @now: (transfer none): the current monotonic time
+ * @now: the current monotonic time
  *
  * Get the amount of milliseconds till the session will expire.
  *
@@ -672,7 +672,10 @@ gst_rtsp_session_next_timeout_usec (GstRTSPSession * session, gint64 now)
  * Deprecated: Use gst_rtsp_session_next_timeout_usec() instead.
  */
 #ifndef GST_REMOVE_DEPRECATED
-#ifndef GST_DISABLE_DEPRECATED
+#ifdef GST_DISABLE_DEPRECATED
+gint gst_rtsp_session_next_timeout (GstRTSPSession * session, GTimeVal * now);
+#endif
+
 gint
 gst_rtsp_session_next_timeout (GstRTSPSession * session, GTimeVal * now)
 {
@@ -709,12 +712,11 @@ gst_rtsp_session_next_timeout (GstRTSPSession * session, GTimeVal * now)
   return res;
 }
 #endif
-#endif
 
 /**
  * gst_rtsp_session_is_expired_usec:
  * @session: a #GstRTSPSession
- * @now: (transfer none): the current monotonic time
+ * @now: the current monotonic time
  *
  * Check if @session timeout out.
  *
@@ -745,7 +747,9 @@ gst_rtsp_session_is_expired_usec (GstRTSPSession * session, gint64 now)
  * Deprecated: Use gst_rtsp_session_is_expired_usec() instead.
  */
 #ifndef GST_REMOVE_DEPRECATED
-#ifndef GST_DISABLE_DEPRECATED
+#ifdef GST_DISABLE_DEPRECATED
+gboolean gst_rtsp_session_is_expired (GstRTSPSession * session, GTimeVal * now);
+#endif
 gboolean
 gst_rtsp_session_is_expired (GstRTSPSession * session, GTimeVal * now)
 {
@@ -756,4 +760,3 @@ gst_rtsp_session_is_expired (GstRTSPSession * session, GTimeVal * now)
   return res;
 }
 #endif
-#endif
